<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Data::SyncthingLauncher</name>
    <message>
        <location filename="../misc/syncthinglauncher.cpp" line="76"/>
        <source>Not built with libsyncthing support.</source>
        <translation>Unterstützung für libsyncthing nicht aktiviert.</translation>
    </message>
</context>
<context>
    <name>QtGui::AppearanceOptionPage</name>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="6"/>
        <source>Appearance</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="19"/>
        <source>Menu size</source>
        <translation>Größe des Menüs</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="94"/>
        <source>Optional GUI elements</source>
        <translation>Optionale Elemente</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="101"/>
        <source>Traffic statistics</source>
        <translation>Traffic-Statistiken</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="50"/>
        <source> x </source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="28"/>
        <location filename="../settings/appearanceoptionpage.ui" line="60"/>
        <location filename="../settings/appearanceoptionpage.ui" line="257"/>
        <location filename="../settings/appearanceoptionpage.ui" line="286"/>
        <source> px</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="108"/>
        <source>Frame shape</source>
        <translation>Rahmenform</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="139"/>
        <source>Frame shadow</source>
        <translation>Rahmenschatten</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="116"/>
        <source>No frame</source>
        <translation>Kein Rahmen</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="121"/>
        <source>Box</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="126"/>
        <source>Panel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="131"/>
        <source>Styled panel</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="147"/>
        <source>Plain</source>
        <translation>Einfach</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="152"/>
        <source>Raised</source>
        <translation>Angehoben</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="157"/>
        <source>Sunken</source>
        <translation>Eingedrückt</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="165"/>
        <source>Tab position</source>
        <translation>Position der Tabs</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="173"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="178"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="183"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="188"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="196"/>
        <source>Colors</source>
        <translation>Farben</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="203"/>
        <source>Bright custom text colors (use for dark color scheme)</source>
        <translation>Helle benutzerdefinierte Schriftfarben (für dunkles Farbschema gedacht)</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="210"/>
        <source>Positioning</source>
        <translation>Menüposition</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="222"/>
        <source>Use cursor position</source>
        <translation>Verwende Mausposition</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="232"/>
        <source>Otherwise assume tray icon coordinates to be:</source>
        <translation>Andernfalls folgende Koordinaten verwenden:</translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="250"/>
        <source>x:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/appearanceoptionpage.ui" line="276"/>
        <source>y:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtGui::AutostartOptionPage</name>
    <message>
        <location filename="../settings/autostartoptionpage.ui" line="6"/>
        <source>Autostart</source>
        <translation>Auto-Start</translation>
    </message>
    <message>
        <location filename="../settings/autostartoptionpage.ui" line="18"/>
        <source>Start the tray icon when the desktop environment launches</source>
        <translation>Tray-Icon beim Starten der Desktopumgebung automatisch starten</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="666"/>
        <source>This is achieved by adding a *.desktop file under &lt;i&gt;~/.config/autostart&lt;/i&gt; so the setting only affects the current user.</source>
        <translation>Durch das Hinzufügen einer *.desktop-Datei unter &lt;i&gt;~/.config/autostart&lt;/i&gt; realisiert - betrifft also nur den aktuellen Benutzer.</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="669"/>
        <source>This is achieved by adding a registry key under &lt;i&gt;HKEY_CURRENT_USER\SOFTWARE\Microsoft\Windows\CurrentVersion\Run&lt;/i&gt; so the setting only affects the current user. Note that the startup entry is invalidated when moving &lt;i&gt;syncthingtray.exe&lt;/i&gt;.</source>
        <translation>Durch das Hinzufügen eines Registry-Schlüssels unter &lt;i&gt;HKEY_CURRENT_USER\SOFTWARE\Microsoft\Windows\CurrentVersion\Run&lt;/i&gt; realisiert - betrifft also nur den aktuellen Benutzer.</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="673"/>
        <source>This is achieved by adding a *.plist file under &lt;i&gt;~/Library/LaunchAgents&lt;/i&gt; so the setting only affects the current user.</source>
        <translation>Durch das Hinzufügen einer *.plist-Datei unter &lt;i&gt;~/Library/LaunchAgents&lt;/i&gt; realisiert - betrifft also nur den aktuellen Benutzer.</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="677"/>
        <source>This feature has not been implemented for your platform (yet).</source>
        <translation>Diese Funktion wurde für die aktuelle Plattform nicht nicht implementiert.</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="808"/>
        <source>unable to modify startup entry</source>
        <translation>Fehler beim aktualisieren des Auto-Start-Eintrags</translation>
    </message>
</context>
<context>
    <name>QtGui::ConnectionOptionPage</name>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="6"/>
        <source>Connection</source>
        <translation>Verbindung</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="25"/>
        <source>Config label</source>
        <translation>Name der Konfig.</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="75"/>
        <source>Move currently selected configuration down</source>
        <translation>Aktuelle Konfiguration in der Liste nach unten schieben</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="107"/>
        <source>Add secondary instance</source>
        <translation>Sekundäre Konfiguration hinzufügen</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="124"/>
        <source>Remove currently selected secondary instance</source>
        <translation>Sekundäre Konfiguration löschen</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="177"/>
        <source>Syncthing URL</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="187"/>
        <source>Authentication</source>
        <translation>Authentifizierung</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="200"/>
        <source>User</source>
        <translation>Benutzername</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="217"/>
        <source>Password</source>
        <translation>Passwort</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="234"/>
        <source>API key</source>
        <translation>API-Schlüssel</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="244"/>
        <source>HTTPS certificate</source>
        <translation>HTTPS-Zertifikat</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="264"/>
        <source>Insert values from local Syncthing configuration</source>
        <translation>Werte aus lokaler Syncthing-Konfiguration einfügen</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="365"/>
        <source>Errors</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="426"/>
        <source>Status</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="433"/>
        <source>disconnected</source>
        <translation>getrennt</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="440"/>
        <source>Apply connection settings and try to reconnect with the currently selected config</source>
        <translation>Verbindungseinstellungen übernehmen und mit neuen Einstellungen verbinden</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="288"/>
        <source>Poll interval</source>
        <translation>Abfrageintervall</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="325"/>
        <source>Traffic</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="312"/>
        <location filename="../settings/connectionoptionpage.ui" line="352"/>
        <location filename="../settings/connectionoptionpage.ui" line="378"/>
        <location filename="../settings/connectionoptionpage.ui" line="407"/>
        <source> ms</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="91"/>
        <source>Move currently selected configuration up</source>
        <translation>Aktuelle Konfiguration in der Liste nach oben schieben</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="154"/>
        <source>It is possible to save multiple configurations. This allows switching quickly between multiple Syncthing instances using the connection button in the right corner of the tray menu. The config label is an arbitrary name to identify a configuration and does not have to match the name of the corresponding Syncthing device. The first configuration is the primary/default configuration.</source>
        <translation>Es ist möglich, mehrere Konfigurationen zu speichern. Zwischen diesen kann anschließend über das Verbindungsmenü rechts oben im Tray schnell hin- und hergewechselt werden. Der Name der Konfiguration muss nicht mit dem Namen des entsprechenden Syncthing-Gerätes übereinstimmen. Die erste Konfiguration in der Liste ist die Standardkonfiguration.</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="332"/>
        <source>Device statistics</source>
        <translation>Gerätestatistiken</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="391"/>
        <source>Reconnect</source>
        <translation>Verbindungsveruch</translation>
    </message>
    <message>
        <location filename="../settings/connectionoptionpage.ui" line="404"/>
        <source>no</source>
        <translation>nicht neu verbinden</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="87"/>
        <source>Auto-detected for local instance</source>
        <translation>Kann für lokale Instanz automatisch ermittelt werden</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="109"/>
        <source>Select Syncthing config file</source>
        <translation>Wähle die Syncthing-Konfigurationsdatei</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="117"/>
        <source>Unable to parse the Syncthing config file.</source>
        <translation>Fehler beim Auslesen der Syncthing-Konfigurationsdatei.</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="202"/>
        <source>Unable to load specified certificate &quot;%1&quot;.</source>
        <translation>Fehler beim Auslesen des angegebenen Zertifikats: %1</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="227"/>
        <source>Instance %1</source>
        <translation>Instanz %1</translation>
    </message>
</context>
<context>
    <name>QtGui::DBusStatusNotifier</name>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="25"/>
        <source> - internal error</source>
        <translation> - interner Fehler</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="26"/>
        <source> - launcher error</source>
        <translation> - Starter-Fehler</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="27"/>
        <source>Syncthing notification</source>
        <translation>Syncthing-Benachrichtigung</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="29"/>
        <source> - new device</source>
        <translation>- neues Gerät</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="30"/>
        <source> - new directory</source>
        <translation>- neues Verzeichnis</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="33"/>
        <source>Disconnected from Syncthing</source>
        <translation>Verbindung zu Syncthing getrennt</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="34"/>
        <source>Try to reconnect</source>
        <translation>Versuche Verbindung wieder herzustellen</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="38"/>
        <location filename="../misc/dbusstatusnotifier.cpp" line="42"/>
        <source>View details</source>
        <translation>Zeige details</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="46"/>
        <source>Show</source>
        <translation>Zeigen</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="46"/>
        <source>Dismiss</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <location filename="../misc/dbusstatusnotifier.cpp" line="52"/>
        <source>Open web UI</source>
        <translation>Öffne Web-UI</translation>
    </message>
</context>
<context>
    <name>QtGui::DirectoryErrorsDialog</name>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="28"/>
        <source>Errors for directory %1</source>
        <translation>Fehler für Verzeichnis %1</translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="46"/>
        <source>Remove non-empty directories</source>
        <translation>Nicht-leere Verzeichnisse löschen</translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/direrrorsdialog.cpp" line="83"/>
        <source>%1 item(s) out-of-sync</source>
        <translation>
            <numerusform>%1 Element nicht synchronisiert</numerusform>
            <numerusform>%1 Elemente nicht synchronisiert</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="113"/>
        <source>Remove non-empty directories for folder &quot;%1&quot;</source>
        <translation>Nicht-leere Verzeichnisse für den Ordner &quot;%1&quot; löschen</translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="114"/>
        <source>Do you really want to remove the following directories:</source>
        <translation>Sollen die folgenden Verzeichnisse wirklich gelöscht werden?</translation>
    </message>
    <message>
        <location filename="../misc/direrrorsdialog.cpp" line="137"/>
        <source>Unable to remove the following dirs:</source>
        <translation>Die folgenden Verzeichnisse konnten nicht gelöscht werden:</translation>
    </message>
</context>
<context>
    <name>QtGui::IconsOptionPage</name>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="6"/>
        <source>Icons</source>
        <translation>Symbole</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="22"/>
        <source>Status icons</source>
        <translation>Status-Icons</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="30"/>
        <source>Background color 1</source>
        <translation>Hintergrundfarbe 1</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="40"/>
        <source>Background color 2</source>
        <translation>Hintergrundfarbe 2</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="50"/>
        <source>Preview</source>
        <translation>Vorschau</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="63"/>
        <source>Foreground color</source>
        <translation>Vordergrundfarbe</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="97"/>
        <source>Restore previous settings</source>
        <translation>Auf vorherige Farben zurücksetzen</translation>
    </message>
    <message>
        <location filename="../settings/iconsoptionpage.ui" line="108"/>
        <source>Restore defaults</source>
        <translation>Auf Standardfarben zurücksetzen</translation>
    </message>
</context>
<context>
    <name>QtGui::IconsOptionPageBase</name>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="529"/>
        <source>UI icons</source>
        <translation>UI-Icons</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="531"/>
        <source>These icon colors are used within Syncthing Tray&apos;s UI.</source>
        <translation>Diese Icon-Farben werden innerhalb der Oberfläche von Syncthing Tray verwendet.</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="535"/>
        <source>System icons</source>
        <translation>System-Icons</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="537"/>
        <source>These icon colors are used for the system tray icon and the notifications.</source>
        <translation>Diese Icon-Farben werden für das System-Tray-Icon und Benachrichtigungen verwendet.</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="538"/>
        <source>Use same colors as for UI icons</source>
        <translation>Die selben Farben wie für UI-Icons verwenden</translation>
    </message>
</context>
<context>
    <name>QtGui::InternalErrorsDialog</name>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="25"/>
        <source>Internal errors</source>
        <translation>Interne Fehler</translation>
    </message>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="26"/>
        <source>Request URL:</source>
        <translation>URL der Anfrage:</translation>
    </message>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="27"/>
        <source>Response:</source>
        <translation>Antwort:</translation>
    </message>
    <message>
        <location filename="../misc/internalerrorsdialog.cpp" line="53"/>
        <source>Clear errors</source>
        <translation>Liste der Fehler löschen</translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/internalerrorsdialog.cpp" line="101"/>
        <source>%1 error(s) occured</source>
        <translation>
            <numerusform>%1 interner Fehler</numerusform>
            <numerusform>%1 interne Fehler</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>QtGui::LauncherOptionPage</name>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="6"/>
        <source>Syncthing launcher</source>
        <translation>Syncthing-Starter</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="18"/>
        <source>Launch Syncthing when starting the tray icon</source>
        <translation>Starte Syncthing beim Starten des Tray-Icons</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="40"/>
        <source>Syncthing executable</source>
        <translation>Ausführbare Datei von Syncthing</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="50"/>
        <source>Arguments</source>
        <translation>Argumente</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="60"/>
        <source>Use built-in Syncthing library</source>
        <translation>Verwende eingebaute Syncthing-Bibliothek</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="67"/>
        <source>Config directory</source>
        <translation>Konfigurationsverzeichnis</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="80"/>
        <source>Show start/stop button on tray for local instance</source>
        <translation>Zeige Start/Stop-Button für die lokale Instanz</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="87"/>
        <source>Consider process status for reconnect attempts to local instance
 • Don&apos;t reconnect when the process is not running
 • Try to reconnect when starting the process</source>
        <translation>Verwende den Status des Starters für Neuverbindungsversuche zur lokalen Instanz
 • Nicht versuchen neu zu verbinden, wenn Syncthing nicht läuft
 • Automatisch neu verbinden, wenn Syncthing gestartet wird</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="117"/>
        <source>Syncthing log (interleaved stdout/stderr)</source>
        <translation>Syncthing-Log (stdout/stderr)</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="130"/>
        <source>Apply and launch now</source>
        <translation>Jetzt starten</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="147"/>
        <location filename="../settings/settingsdialog.cpp" line="953"/>
        <source>Stop launched instance</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="166"/>
        <source>No log messages available yet</source>
        <translation>Bisher keine Log-Meldungen</translation>
    </message>
    <message>
        <location filename="../settings/launcheroptionpage.ui" line="173"/>
        <source>Ensure latest log is visible</source>
        <translation>Log folgen</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="853"/>
        <source>%1-launcher</source>
        <translation>%1-Starter</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="854"/>
        <source>Launch %1 when starting the tray icon</source>
        <translation>Starte %1 beim Starten des Tray-Icons</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="855"/>
        <source>%1 executable</source>
        <translation>Ausführbare Datei von %1</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="856"/>
        <source>%1 log (interleaved stdout/stderr)</source>
        <translation>%1-Log (stdout/stderr)</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="868"/>
        <source>Restore default</source>
        <translation>Auf Vorgabe zurücksetzen</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="988"/>
        <source>%1 exited with exit code %2</source>
        <translation>%1 wurde mit dem Statuscode %2 beendet</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="991"/>
        <source>%1 crashed with exit code %2</source>
        <translation>%1 ist mit dem Statuscode %2 abgestürzt</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1018"/>
        <source>failed to start (e.g. executable does not exist or not permission error)</source>
        <translation>Start fehlgeschlagen (z. B. weil Programmdatei nicht existiert oder nicht ausführbar ist)</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1021"/>
        <source>process crashed</source>
        <translation>Prozess ist abgestürzt</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1024"/>
        <source>timeout error</source>
        <translation>Time-out</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1027"/>
        <source>read error</source>
        <translation>Lesefehler</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1030"/>
        <source>write error</source>
        <translation>Schreibfehler</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1033"/>
        <source>unknown process error</source>
        <translation>unbekannter Fehler</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1035"/>
        <source>An error occurred when running %1: %2</source>
        <translation>Beim Ausführen von %1 ist ein Fehler aufgetreten: %2</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1081"/>
        <source>Kill launched instance</source>
        <translation>Töten</translation>
    </message>
</context>
<context>
    <name>QtGui::NotificationsOptionPage</name>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="6"/>
        <source>Notifications</source>
        <translation>Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="16"/>
        <source>Notify on</source>
        <translation>Benachrichtigen, wenn</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="22"/>
        <source>disconnect</source>
        <translation>die Verbindung zu Syncthing getrennt wird</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="29"/>
        <source>internal errors</source>
        <translation>interne Fehler auftreten</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="36"/>
        <source>errors/notifications from Syncthing</source>
        <translation>Fehler/Warnungen von Syncthing gemeldet werden</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="43"/>
        <source>sync of local directory complete</source>
        <translation>die Synchronisation lokaler Verzeichnisse abgeschlossen wurde</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="50"/>
        <source>sync of remote directory complete</source>
        <translation>die Synchronisation von Verzeichnissen auf anderen Geräten abgeschlossen wurde</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="57"/>
        <source>new/unknown device connects</source>
        <translation>ein neues/unbekanntes Gerät versucht zu verbinden</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="64"/>
        <source>remote device shares new/unknown directory</source>
        <translation>ein anderes Geräte ein neues/unbekanntes Verzeichnis teilen möchte</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="71"/>
        <source>errors of Syncthing launcher</source>
        <translation>Fehler des Syncthing-Starters</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="81"/>
        <source>Notification API</source>
        <translation>Benachrichtigungs-API</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="87"/>
        <source>D-Bus &amp;notifications (org.freedesktop.Notifications)</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="110"/>
        <source>Ignore inavailability of Syncthing the specified number of seconds after Syncthing has been started; has only effect if the Syncthing start can be determined which is currently only supported for the local instance started via Systemd or the internal launcher.</source>
        <translation>Ignoriere, dass Syncthing ein paar Sekunden nach dem Start noch nicht verfügbar ist. Hat nur Auswirkungen, wenn der Syncthing-Startzeitpunkt ermittelt werden kann. Dies wird aktuell nur für die lokale Instanz unterstützt. Diese muss hierfür über Systemd oder die Tray-Anwendung gestartet worden sein.</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="94"/>
        <source>&amp;Method provided by Qt (might be overridden by QPA plugin)</source>
        <translation>Methode die von Qt verwendet wird (kann vom QPA-Plugin überschrieben werden)</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="104"/>
        <source>Misc</source>
        <translation>Verschiedenes</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="120"/>
        <source>don&apos;t ignore</source>
        <translation>nicht ignorieren</translation>
    </message>
    <message>
        <location filename="../settings/notificationsoptionpage.ui" line="123"/>
        <source> s</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="387"/>
        <source>Configured to use D-Bus notifications but D-Bus notification daemon seems unavailabe.</source>
        <translation>Benachrichtigungen via D-Bus wurden eingestellt, aber es scheint kein Daemon zu laufen der den Dienst bereitstellt.</translation>
    </message>
</context>
<context>
    <name>QtGui::OtherDialogs</name>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="27"/>
        <source>Own device ID</source>
        <translation>Eigene Geräte-ID</translation>
    </message>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="37"/>
        <source>device ID is unknown</source>
        <translation>Geräte-ID ist unbekannt</translation>
    </message>
    <message>
        <location filename="../misc/otherdialogs.cpp" line="45"/>
        <source>Copy to clipboard</source>
        <translation>In Zwischenablage kopieren</translation>
    </message>
</context>
<context>
    <name>QtGui::SettingsDialog</name>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1280"/>
        <source>Tray</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1287"/>
        <source>Web view</source>
        <translation>Weboberfläche</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1294"/>
        <source>Startup</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1316"/>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
</context>
<context>
    <name>QtGui::StatusInfo</name>
    <message>
        <location filename="../misc/statusinfo.cpp" line="17"/>
        <source>Initializing ...</source>
        <translation>Initialisierung ...</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="43"/>
        <location filename="../misc/statusinfo.cpp" line="47"/>
        <source>Not connected to Syncthing</source>
        <translation>Nicht mit Syncthing verbunden</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="52"/>
        <source>Reconnecting ...</source>
        <translation>Neu verbinden ...</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="60"/>
        <location filename="../misc/statusinfo.cpp" line="64"/>
        <source>At least one directory is out of sync</source>
        <translation>Mind. ein Verzeichnis hat Fehler</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="68"/>
        <source>Notifications available</source>
        <translation>Es gibt neue Benachrichtigungen</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="73"/>
        <source>Syncthing is idling</source>
        <translation>Syncthing ist im Leerlauf</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="77"/>
        <source>Syncthing is scanning</source>
        <translation>Syncthing scannt</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="81"/>
        <source>At least one device is paused</source>
        <translation>Mind. ein Gerät ist pausiert</translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/statusinfo.cpp" line="136"/>
        <source>Connected to %1 devices</source>
        <translation>
            <numerusform>Mit %1 Gerät verbunden</numerusform>
            <numerusform>Mit %1 Geräten verbunden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/statusinfo.cpp" line="139"/>
        <source>Connected to %1 and %2 other devices</source>
        <translation>
            <numerusform>Mit %1 und einem weiteren Gerät verbunden</numerusform>
            <numerusform>Mit %1 und %2 weiteren Geräten verbunden</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/statusinfo.cpp" line="143"/>
        <source>Connected to %1 and %2</source>
        <translation>
            <numerusform>Mit %1 und %2 verbunden</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../misc/statusinfo.cpp" line="146"/>
        <source>Connected to %1</source>
        <translation>
            <numerusform>Mit %1 verbunden</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="59"/>
        <location filename="../misc/statusinfo.cpp" line="85"/>
        <source>Synchronization is ongoing</source>
        <translation>Syncthing synchronisiert</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="45"/>
        <source>Trying to reconnect every %1 ms</source>
        <translation>Versuche alle %1 ms zu verbinden</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="89"/>
        <source>Status is unknown</source>
        <translation>Status ist unbekannt</translation>
    </message>
    <message>
        <location filename="../misc/statusinfo.cpp" line="112"/>
        <source>Not connected to other devices</source>
        <translation>Nicht mit anderen Geräten verbunden</translation>
    </message>
</context>
<context>
    <name>QtGui::SyncthingKiller</name>
    <message>
        <location filename="../misc/syncthingkiller.cpp" line="53"/>
        <source>The process %1 (PID: %2) has been requested to terminate but hasn&apos;t reacted yet. Kill the process?

This dialog closes automatically when the process finally terminates.</source>
        <translation>Der Prozess %1 (PID: %2) wurde aufgefordert sich zu beenden, reagiert aber nicht. Soll der Prozess getötet werden?

Dieser Dialog schließt sich automatisch, wenn der Prozess beendet wird.</translation>
    </message>
    <message>
        <location filename="../misc/syncthingkiller.cpp" line="59"/>
        <source>Keep running</source>
        <translation>Prozess laufen lassen</translation>
    </message>
    <message>
        <location filename="../misc/syncthingkiller.cpp" line="60"/>
        <source>Kill process</source>
        <translation>Prozess töten</translation>
    </message>
</context>
<context>
    <name>QtGui::SystemdOptionPage</name>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="6"/>
        <source>Systemd</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="18"/>
        <source>Show start/stop button on tray for local instance when systemd is available</source>
        <translation>Zeige Start/Stop-Button für die lokale Instanz wenn systemd verfügbar ist</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="62"/>
        <source>Syncthing unit</source>
        <translation>Syncthing-Unit</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="78"/>
        <source>Description</source>
        <translation>Beschreibung</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="114"/>
        <source>Current status</source>
        <translation>Aktueller Status</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="191"/>
        <source>Unit file state</source>
        <translation>Status des Unit files</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="99"/>
        <location filename="../settings/systemdoptionpage.ui" line="154"/>
        <location filename="../settings/systemdoptionpage.ui" line="231"/>
        <location filename="../settings/settingsdialog.cpp" line="1195"/>
        <location filename="../settings/settingsdialog.cpp" line="1207"/>
        <source>unknown</source>
        <translation>unbekannt</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="25"/>
        <source>Consider systemd unit status for reconnect attempts to local instance
 • Don&apos;t reconnect when unit not active/running
 • Try to reconnect when unit becomes active/running</source>
        <translation>Verwende den systemd-Status für Neuverbindungsversuche zur lokalen Instanz
 • Nicht versuchen neu zu verbinden, wenn die Syncthing-Unit nicht läuft
 • Automatisch neu verbinden, wenn die Syncthing-Unit gestartet wird</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="238"/>
        <source>Enable</source>
        <translation>Autom. starten</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="249"/>
        <source>Disable</source>
        <translation>Nicht autom. starten</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="161"/>
        <source>Start</source>
        <translation>Starten</translation>
    </message>
    <message>
        <location filename="../settings/systemdoptionpage.ui" line="172"/>
        <source>Stop</source>
        <translation>Stoppen</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1137"/>
        <source>It is not possible to show the start/stop button for the systemd service and the internal launcher at the same time. The systemd service precedes.</source>
        <translation>Es ist nicht möglich, den Start-/Stop-Button für den Systemd-Dienst und den internen Starter gleichzeitig anzugeigen. Wenn verfügbar, wird der Button den Systemd-Dienst kontrollieren.</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1143"/>
        <source>It is not possible to consider the systemd service and the internal launcher for reconnects at the same time. The systemd service precedes.</source>
        <translation>Es ist nicht möglich, den Status des Systemd-Dienstes und den des internen Starters gleichzeitig für Verbindungsveruche einzubeziehen. Wenn verfügbar, wird der Status des Systemd-Dienstes verwendet.</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1168"/>
        <source>specified unit is either inactive or doesn&apos;t exist</source>
        <translation>angegebene Unit entweder nicht geladen oder existiert nicht</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1190"/>
        <source>since </source>
        <translation>seit </translation>
    </message>
</context>
<context>
    <name>QtGui::TextViewDialog</name>
    <message>
        <location filename="../misc/textviewdialog.cpp" line="61"/>
        <location filename="../misc/textviewdialog.cpp" line="70"/>
        <source>Log</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtGui::WebPage</name>
    <message>
        <location filename="../webview/webpage.cpp" line="285"/>
        <source>Select path for Syncthing directory ...</source>
        <translation>Pfad für Syncthing-Verzeichnis auswählen ...</translation>
    </message>
</context>
<context>
    <name>QtGui::WebViewDialog</name>
    <message>
        <location filename="../webview/webviewdialog.cpp" line="25"/>
        <source>Syncthing</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>QtGui::WebViewOptionPage</name>
    <message>
        <location filename="../settings/webviewoptionpage.ui" line="6"/>
        <location filename="../settings/settingsdialog.cpp" line="1229"/>
        <source>General</source>
        <translation>Allgemein</translation>
    </message>
    <message>
        <location filename="../settings/webviewoptionpage.ui" line="12"/>
        <source>Usage</source>
        <translation>Verwendung</translation>
    </message>
    <message>
        <location filename="../settings/webviewoptionpage.ui" line="19"/>
        <source>Disable web view (open regular web browser instead)</source>
        <translation>Eingebaute Anzeige deaktivieren (stattdessen Standardbrowser verwenden)</translation>
    </message>
    <message>
        <location filename="../settings/webviewoptionpage.ui" line="26"/>
        <source>Zoom factor</source>
        <translation>Zoom-Faktor</translation>
    </message>
    <message>
        <location filename="../settings/webviewoptionpage.ui" line="49"/>
        <source>Hiding</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <location filename="../settings/webviewoptionpage.ui" line="56"/>
        <source>Keep web view running when currently not shown</source>
        <translation>Lasse Weboberfläche im Hintgergrund weiter offen, wenn Fenster nicht offen</translation>
    </message>
    <message>
        <location filename="../settings/settingsdialog.cpp" line="1231"/>
        <source>Syncthing Tray has not been built with vieb view support utilizing either Qt WebKit or Qt WebEngine.
The Web UI will be opened in the default web browser instead.</source>
        <translation>Syncthing Tray wurde nicht mit Unterstützung für die eingebaute Anzeige der Weboberfläche unter Verwendung von Qt WebKit oder Qt WebEngine gebaut.
Die Weboberfläche wird stattdessen im Standardwebrowser geöffnet.</translation>
    </message>
</context>
<context>
    <name>Settings::restore</name>
    <message>
        <location filename="../settings/settings.cpp" line="231"/>
        <source>Unable to load certificate &quot;%1&quot; when restoring settings.</source>
        <translation>Fehler beim laden des Zertifikats &quot;%1&quot; beim wiederherstellen der Einstellungen.</translation>
    </message>
</context>
</TS>
